@@ -9,13 +9,16 @@ MogileFS::Client - Client library for the MogileFS distributed file system.
 
  use MogileFS::Client;
 
- # create client object w/ server-configured namespace and IPs of trackers
+ # create client object w/ server-configured namespace 
+ # and IPs of trackers
  $mogc = MogileFS::Client->new(domain => "foo.com::my_namespace",
                                hosts  => ['10.0.0.2', '10.0.0.3']);
 
  # create a file
- $key   = "image_of_userid:$userid";   # mogile is a flat namespace.  no paths.
- $class = "user_images";               # must be configured on server
+ # mogile is a flat namespace.  no paths.
+ $key   = "image_of_userid:$userid";   
+ # must be configured on server
+ $class = "user_images";               
  $fh = $mogc->new_file($key, $class);
 
  print $fh $data;
@@ -24,7 +27,8 @@ MogileFS::Client - Client library for the MogileFS distributed file system.
     die "Error writing file: " . $mogc->errcode . ": " . $mogc->errstr;
  }
 
- # Find the URLs that the file was replicated to.  May change over time.
+ # Find the URLs that the file was replicated to.
+ # May change over time.
  @urls = $mogc->get_paths($key);
 
  # no longer want it?
@@ -51,7 +55,7 @@ use Time::HiRes ();
 use MogileFS::Backend;
 use MogileFS::NewHTTPFile;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 our $AUTOLOAD;
 
@@ -373,6 +377,10 @@ sub store_content {
 Given a key, returns an array of all the locations (HTTP URLs) that
 the file has been replicated to.
 
+=over
+
+=item noverify
+
 If the "no verify" option is set, the mogilefsd tracker doesn't verify
 that the first item returned in the list is up/alive.  Skipping that
 check is faster, so use "noverify" if your application can do it
@@ -380,12 +388,26 @@ faster/smarter.  For instance, when giving L<Perlbal> a list of URLs
 to reproxy to, Perlbal can intelligently find one that's alive, so use
 noverify and get out of mod_perl or whatever as soon as possible.
 
+=item zone
+
+If the zone option is set to 'alt', the mogilefsd tracker will use the
+alternative IP for each host if available, while constructing the paths.
+
+=item pathcount
+
+If the pathcount option is set to a positive integer greater than 2, the
+mogilefsd tracker will attempt to return that many different paths (if
+available) to the same file. If not present or out of range, this value
+defaults to 2.
+
+=back
+
 =cut
 
 # old style calling:
 #   get_paths(key, noverify)
 # new style calling:
-#   get_paths(key, { noverify => 0/1, zone => "zone" });
+#   get_paths(key, { noverify => 0/1, zone => "alt", pathcount => 2..N });
 # but with both, second parameter is optional
 #
 # returns list of URLs that key can be found at, or the empty
